pub fn evaluate(
config: &FleetConfig,
target_nodes: &[String],
action: DeployAction,
max_parallel: usize,
) -> Result<DeploymentPlan>Expand description
Evaluate which hosts need deployment by comparing desired vs current state.
pub fn evaluate(
config: &FleetConfig,
target_nodes: &[String],
action: DeployAction,
max_parallel: usize,
) -> Result<DeploymentPlan>Evaluate which hosts need deployment by comparing desired vs current state.